package require marvin

initParamPsfPdb \
    -paramFileName $env(XPLOR_DIR)/toppar/parallhdg_procheck.pro \
    -psfFileName   cvn.psf \
    -pdbFileName   cvn_reference.pdb

set noe [create_LinearNOEPotential exptNOEs]

readMarvinRestraints \
    -fileName cvn_none_final_noes.tbl \
    -pot $noe

proc likelihoodEqualTo {target aRestraintPtr} {

    if {[isLinearRestraint $aRestraintPtr]} {
	LinearRestraint tempRaw -this $aRestraintPtr

    } elseif {[isQuadraticRestraint $aRestraintPtr]} {
	QuadraticRestraint tempRaw -this $aRestraintPtr

    } else {
	error "likelihoodGreaterThan called on something that's not a raw NOE: $aRestraintPtr"
    }

    set l [tempRaw previousLikelihood]
    rename tempRaw ""

    if {$l == $target} {
	return 1
    } else {
	return 0
    }
}


proc likelihoodBetween {targetList aRestraintPtr} {

    if {[isLinearRestraint $aRestraintPtr]} {
	LinearRestraint tempRaw -this $aRestraintPtr

    } elseif {[isQuadraticRestraint $aRestraintPtr]} {
	QuadraticRestraint tempRaw -this $aRestraintPtr

    } else {
	error "likelihoodGreaterThan called on something that's not a raw NOE: $aRestraintPtr"
    }

    set l [tempRaw previousLikelihood]
    rename tempRaw ""

    if {($l > [lindex $targetList 0]) && ($l < [lindex $targetList 1])} {
	return 1
    } else {
	return 0
    }
}


proc fracGood {rList} {

    set tempL [selectNOErestraints -from $rList -proc {violLessThan 0.5}]

    return [expr [llength $tempL] / double([llength $rList])]
}


set all [$noe restraints]

set sr [selectNOErestraints -from $all -proc {sequenceDistLessThan 6}]
set lr [selectNOErestraints -from $all -proc {sequenceDistGreaterThan 5}]

set bins [list {0 0.1} {0.1 0.2} {0.2 0.3} {0.3 0.4} {0.4 0.5} {0.5 0.6} {0.6 0.7} {0.7 0.8} {0.8 0.9} {0.9 1.0}]

puts stderr "long range:"

set curList [selectNOErestraints -from $lr -proc {likelihoodEqualTo 0.0}]
puts stderr [format "0 %d %f" [llength $curList] [fracGood $curList]]

foreach curBin $bins {

    set curList [selectNOErestraints -from $lr -proc [list likelihoodBetween $curBin]]
    puts stderr [format "%s %d %f" $curBin [llength $curList] [fracGood $curList]]
}

set curList [selectNOErestraints -from $lr -proc {likelihoodEqualTo 1.0}]
puts stderr [format "1 %d %f" [llength $curList] [fracGood $curList]]


puts stderr "short range:"

set curList [selectNOErestraints -from $sr -proc {likelihoodEqualTo 0.0}]
puts stderr [format "0 %d %f" [llength $curList] [fracGood $curList]]

foreach curBin $bins {

    set curList [selectNOErestraints -from $sr -proc [list likelihoodBetween $curBin]]
    puts stderr [format "%s %d %f" $curBin [llength $curList] [fracGood $curList]]
}

set curList [selectNOErestraints -from $sr -proc {likelihoodEqualTo 1.0}]
puts stderr [format "1 %d %f" [llength $curList] [fracGood $curList]]


puts stderr "all:"

set curList [selectNOErestraints -from $all -proc {likelihoodEqualTo 0.0}]
puts stderr [format "0 %d %f" [llength $curList] [fracGood $curList]]

foreach curBin $bins {

    set curList [selectNOErestraints -from $all -proc [list likelihoodBetween $curBin]]
    puts stderr [format "%s %d %f" $curBin [llength $curList] [fracGood $curList]]
}

set curList [selectNOErestraints -from $all -proc {likelihoodEqualTo 1.0}]
puts stderr [format "1 %d %f" [llength $curList] [fracGood $curList]]

