#
# cyanovirin test
#

#package require xplornih
package require marvin


#
# initialization
#

initParamPsfPdb \
    -paramFileName $env(XPLOR_DIR)/toppar/parallhdg_procheck.pro \
    -psfFileName   cvn.psf \
    -pdbFileName   cvn_random.pdb


#
# make sure the initial coords have good covalent geometry
#

cleanCovalentGeom 


#
# set up the NOEs
#

XplorCommand "set message off echo off end"

set noe [create_QuadraticNOEPotential exptNOEs]

readMarvinRestraints \
    -fileName cvn_pass3_noes.tbl \
    -pot $noe

#
# set up disulfide bond "NOEs"
#

set dis [create_QuadraticNOEPotential disulfides]

readMarvinRestraints \
    -fileName cvn_disulfides.tbl \
    -pot $dis

$dis setForceConst 30.0
$dis chooseAssignments
$dis setAllRestraintsActive

#
# set up the TALOS restraints
#

set talos [create_XplorPot CDIH]

readTalos \
    -fileName cvn_talos_pred.tab \
    -scale 200.0 \
    -widthScale 1.0 \
    -pot $talos

#
# set up the DELPHIC terms
#

setupDelphicTorsions
set deltorPot [create_XplorPot RAMA]

#
# handle IVM setup
#

setupIVM \
    -excludedBonds [list \
			[list [AtomSel -args "resid 8 and name sg"] [AtomSel -args "resid 22 and name sg"]] \
			[list [AtomSel -args "resid 58 and name sg"] [AtomSel -args "resid 73 and name sg"]]] \
    -toleranceMultiplier 10.0


#
# remarks to tack onto each PDB file
#

set desc "" 

set remList [list $desc]

#
# calculate structures with standard pass3 protocol
#

pass3 \
    -numStructs 500 \
    -outFilenameTemplate $outName \
    -remarksList $remList \
    -potsToUseDuringRandomization [list $dis $talos] \
    -potsToUseDuringAnnealing [list $dis $noe $talos $deltorPot] \
    -noePot $noe \
    -randomSeed 42

