package require marvin

initParamPsfPdb \
    -paramFileName $env(XPLOR_DIR)/toppar/parallhdg_procheck.pro \
    -psfFileName   il4.psf \
    -pdbFileName   il4_xray.pdb


set noe [create_LinearNOEPotential exptNOEs]

readMarvinRestraints \
    -fileName il4_pass3_noes.tbl \
    -pot $noe


proc noeAcc {noes} {
    
    set good [selectNOErestraints -from $noes -proc [list violLessThan 0.5]]

    if {[llength $noes] > 0} {
	set f [expr [llength $good] / double([llength $noes])]
    } else {
	set f -1
    }

    return $f
}


set all [$noe restraints]


set longRange  [selectNOErestraints -from $all -proc [list sequenceDistGreaterThan 5]]    
set shortRange [selectNOErestraints -from $all -proc [list sequenceDistLessThan 6]]
set intra      [selectNOErestraints -from $all -proc [list sequenceDistLessThan 1]]

set temp       [selectNOErestraints -from $all -proc [list sequenceDistLessThan 2]]
set seqen      [selectNOErestraints -from $temp -proc [list sequenceDistGreaterThan 0]]

set temp       [selectNOErestraints -from $all -proc [list sequenceDistLessThan 6]]
set medium     [selectNOErestraints -from $temp -proc [list sequenceDistGreaterThan 1]]

# set glr [selectNOErestraints -from $longRange  -proc [list violLessThan $violCutoff]]
# set gsr [selectNOErestraints -from $shortRange -proc [list violLessThan $violCutoff]]
	

proc stats {rList} {

    set edges [list {-1 0.099} {0.1 0.199} {0.2 0.299} {0.3 0.399} {0.4 0.499} {0.5 0.599} {0.6 0.699} {0.7 0.799} \
		   {0.8 0.899} {0.9 0.999} {0.999 2.0}]
    
    
    foreach edge $edges {
	
	set start [lindex $edge 0]
	set done  [lindex $edge 1]
	
	set temp  [selectNOErestraints -from $rList -proc [list likelihoodGreaterThan $start]]
	set temp2 [selectNOErestraints -from $temp -proc [list likelihoodLessThan $done]]
	
	puts [list $start $done [llength $temp2] [noeAcc $temp2]]
    }
}

puts "everything:"
stats $all

puts "long range:"
stats $longRange

puts "all short range:"
stats $shortRange

puts "intra:"
stats $intra

puts "sequen:"
stats $seqen

puts "medium:"
stats $medium
