#
# IL4 test
#

#package require xplornih
package require marvin

#
# initialization
#

initParamPsfPdb \
    -paramFileName $env(XPLOR_DIR)/toppar/parallhdg_procheck.pro \
    -psfFileName   il4.psf \
    -pdbFileName   il4_extended.pdb


#
# make sure the initial coords have good covalent geometry
#

#cleanCovalentGeom 


#
# set up the NOEs
#

XplorCommand "set message off echo off end"

set noe [create_LinearNOEPotential exptNOEs]

readMarvinRestraints \
    -fileName il4_pass2_noes.tbl \
    -pot $noe

#
# set up disulfide bond "NOEs"
#

set dis [create_QuadraticNOEPotential disulfides]

readMarvinRestraints \
    -fileName il4_disulfides.tbl \
    -pot $dis

$dis setForceConst 30.0
$dis chooseAssignments
$dis setAllRestraintsActive

#
# set up the TALOS restraints
#

set talos [create_XplorPot CDIH]

readTalos \
    -fileName il4_talos_pred.tab \
    -scale 200.0 \
    -pot $talos

#
# set up the DELPHIC terms
#

setupDelphicTorsions
set deltorPot [create_XplorPot RAMA]

#
# set up the Rgyr restraints
#

setupRgyr -restraints [list [AtomSel -args "resid 8:129"]]
set rgyr [create_XplorPot COLL]

#
# handle IVM setup
#

setupIVM \
    -excludedBonds [list \
			[list [AtomSel -args "resid 7 and name sg"] [AtomSel -args "resid 131 and name sg"]] \
			[list [AtomSel -args "resid 28 and name sg"] [AtomSel -args "resid 69 and name sg"]] \
			[list [AtomSel -args "resid 50 and name sg"] [AtomSel -args "resid 103 and name sg"]]] \
    -toleranceMultiplier 10.0


#
# remarks to tack onto each PDB file
#

set desc "" 

set remList [list $desc]

#
# calculate structures with standard pass2 protocol
#

pass2 \
    -numStructs 500 \
    -outFilenameTemplate "il4_pass2_%d.pdb" \
    -remarksList $remList \
    -potsToUseDuringRandomization [list $dis $talos $rgyr] \
    -potsToUseDuringAnnealing [list $dis $noe $talos $deltorPot] \
    -noePot $noe \
    -randomSeed 42

