#
# protein G used as model system
# for testing method to determine ambiguous and incorrect NOEs
#

package require marvin

#
# initialization
#

initParamPsfPdb \
    -paramFileName $env(XPLOR_DIR)/toppar/parallhdg_procheck.pro \
    -psfFileName   g.psf \
    -pdbFileName   g_extended_mini.pdb

#
# handle IVM setup
#

setupIVM \
    -toleranceMultiplier 10.0

#
# make sure the initial coords have good covalent geometry
#

cleanCovalentGeom 

#
# set up the NOEs
#

XplorCommand "set message off echo off end"

set noe [create_LinearNOEPotential linear]

readMarvinRestraints \
    -fileName g_pass1_noes.tbl \
    -pot $noe

#
# set up the secondary structure torsion angles
#

XplorCommand "restraints dihedral @g_secstruct_torsions.tbl end"
set secstruct [create_XplorPot CDIH]

#
# set up the DELPHIC terms
# dihedral angle correlations for good nearest neighbor geometry
#

setupDelphicTorsions
set deltor [create_XplorPot RAMA]

#
# set up the Rgyr restraints
# Use to insure compact structures
#

setupRgyr -restraints [list [AtomSel -args "resid 2:55"]]
set rgyr [create_XplorPot COLL]

#
# remarks to tack onto each PDB file
#

set desc "A protein G test case" 

set remList [list $desc]

#
# calculate structures with standard pass1 protocol
#

pass1 \
    -numStructs 500 \
    -outFilenameTemplate "g_pass1_%d.pdb" \
    -remarksList $remList \
    -potsToUseDuringRandomization [list $secstruct $rgyr] \
    -potsToUseDuringAnnealing [list $noe $secstruct $deltor $rgyr] \
    -noePot $noe \
    -randomSeed 42

