#
# Convert an old xplor NOE table to Marvin format.
#
# Also generates a pile of random NOEs and adds them on.
#
# Records which restraints are violated in the reference struct and by how much,
# along with each restraint's degeneracy and whether or not all of its possible 
# assignments are long-range (>5 residues separation).
#

set numBadRestraintsToAdd   600
set targetAssignsPerRes     2.0
set outName g_pass1_noes.tbl

#
# Note that the xplor format converter isn't as good as the PIPP format 
# converter, because the old xplor format doesn't give any indication of 
# separate assignments--they're all just ORed together in the selections.
# 

package require marvin
package require noerandomizer

initParamPsfPdb \
    -paramFileName $env(XPLOR_DIR)/toppar/parallhdg_procheck.pro \
    -psfFileName   g.psf \
    -pdbFileName   g_xray_withprotons.pdb

set noe [create_LinearNOEPotential linear]


#
# read the xplor-format file of experimental NOEs
#

readXplorNOEs \
    -fileName g_experimental_noes_xplor.tbl \
    -pot $noe \
    -namePrefix "experimental"

#
# generate a list of selection strings for all the non-exchangable protons
#

set selectList [generateNonExchangableSelections]

#
# set the random number seed
#

setMarvinRandomSeed 42

#
# randomly generate a bunch of bad 
# single-assignment NOE restraints 
# from the list of selections
# and add them to the restraints list
#

addBadRestraints \
    -outputPot $noe \
    -selectList $selectList \
    -numToAdd $numBadRestraintsToAdd \
    -namePrefix "random" \
    -upBound 5.0 \
    -lowBound 1.8 \
    -minAcceptableViol 0.5 

#
# randomly generate a bunch of bad
# assignments from the list of selections 
# and tack them onto randomly-chosen NOE restraints
#

set numBadAssignsToAdd [expr round([llength [$noe restraints]] * ($targetAssignsPerRes - 1))]

addBadAssigns \
    -outputPot $noe \
    -selectList $selectList \
    -numToAdd $numBadAssignsToAdd \
    -upBound 5.0 \
    -lowBound 1.8 \
    -minAcceptableViol 0.5

#
# do standard starting analysis of restraints
#

set remarkList [initialRestraintAnalysis \
		    -pot $noe\
		    -referenceStructureFile g_xray_withprotons.pdb ]


writeMarvinNOEs \
    -fileName $outName \
    -pot $noe \
    -remarks $remarkList
